# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2023-2025, by Samuel Williams.

source "https://rubygems.org"

gemspec

# gem "decode", path: "../../ioquatix/decode"

group :maintenance, optional: true do
	gem "bake-modernize"
	gem "bake-gem"
	
	gem "agent-context"
	
	gem "utopia-project" #, path: "../utopia-project"
end

group :test do
	gem "sus"
	gem "covered"
	gem "decode"
	
	gem "rubocop"
	gem "rubocop-md"
	gem "rubocop-socketry"
	
	gem "bake-test"
	gem "bake-test-external"
	
	gem "sus-fixtures-openssl"
	gem "sus-fixtures-async"
end
